Package: gucharmap / 1:9.0.2-1

unicode-source-generation.patch Patch series | download
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
Description: compatibility with the unicode-data package
 Adjust the script used for unicode header file generation for compatibility
 with the Debian unicode-data package.
Author: Steve Langasek <vorlon@debian.org>
Bug-Debian: http://bugs.debian.org/603405
Index: gucharmap-9.0.0/gucharmap/gen-guch-unicode-tables.pl
===================================================================
--- gucharmap-9.0.0.orig/gucharmap/gen-guch-unicode-tables.pl	2016-06-25 02:48:55.760864421 +0200
+++ gucharmap-9.0.0/gucharmap/gen-guch-unicode-tables.pl	2016-06-25 02:48:55.740864121 +0200
@@ -12,7 +12,7 @@
 #  - unicode-versions.h
 #
 # usage: ./gen-guch-unicode-tables.pl UNICODE-VERSION DIRECTORY
 # where DIRECTORY contains UnicodeData.txt Unihan.zip NamesList.txt Blocks.txt Scripts.txt
 #
 # NOTE! Some code copied from glib/glib/gen-unicode-tables.pl; keep in sync!
 
@@ -32,7 +32,7 @@
 Usage: $0 UNICODE-VERSION DIRECTORY [--i18n]
 
 DIRECTORY should contain the following Unicode data files:
-UnicodeData.txt Unihan.zip NamesList.txt Blocks.txt Scripts.txt
+UnicodeData.txt Unihan_Readings.txt.bz2 NamesList.txt Blocks.txt Scripts.txt
 
 which can be found at http://www.unicode.org/Public/UNIDATA/
 
@@ -54,7 +54,7 @@
 for my $f (readdir ($dir))
 {
     $unicodedata_txt = "$d/$f" if ($f =~ /UnicodeData.*\.txt/);
-    $unihan_zip = "$d/$f" if ($f =~ /Unihan.*\.zip/);
+    $unihan_zip = "$d/$f" if ($f =~ /Unihan_Readings\.txt\.bz2/);
     $nameslist_txt = "$d/$f" if ($f =~ /NamesList.*\.txt/);
     $blocks_txt = "$d/$f" if ($f =~ /Blocks.*\.txt/);
     $scripts_txt = "$d/$f" if ($f =~ /Scripts.*\.txt/);
@@ -62,7 +62,7 @@
 }
 
 defined $unicodedata_txt or die "Did not find $d/UnicodeData.txt";
-defined $unihan_zip or die "Did not find $d/Unihan.zip";
+defined $unihan_zip or die "Did not find $d/Unihan_Readings.txt.bz2";
 defined $nameslist_txt or die "Did not find $d/NamesList.txt";
 defined $blocks_txt or die "Did not find $d/Blocks.txt";
 defined $scripts_txt or die "Did not find $d/Scripts.txt";
@@ -12,7 +12,7 @@
 #
 # usage: ./gen-guch-unicode-tables.pl UNICODE-VERSION DIRECTORY
-# where DIRECTORY contains UnicodeData.txt Unihan.zip NamesList.txt Blocks.txt Scripts.txt
+# where DIRECTORY contains UnicodeData.txt Unihan_Readings.txt.bz2 NamesList.txt Blocks.txt Scripts.txt
 #
 # NOTE! Some code copied from glib/glib/gen-unicode-tables.pl; keep in sync!